@@ -1,16 +1,18 @@
 # -*- coding: utf-8 -*-
 from OFS.ObjectManager import BeforeDeleteException
-from zope.interface import Interface
 from zope.interface import implementer
+from zope.interface import Interface
 
 
 class ILinkIntegrityNotificationException(Interface):
-    """ an exception indicating a prevented link integrity breach """
+    """An exception indicating a prevented link integrity breach.
+    """
 
 
 @implementer(ILinkIntegrityNotificationException)
 class LinkIntegrityNotificationException(BeforeDeleteException):
-    """ an exception indicating a prevented link integrity breach """
+    """An exception indicating a prevented link integrity breach.
+    """
 
     def __str__(self):
         args = self.args
